Module: Keys::Swift

Defined in:
lib/core/utils/swift/swift.rb,
lib/core/utils/swift/writer.rb,
lib/core/utils/swift/package.rb,
lib/core/utils/swift/xcframework.rb

Defined Under Namespace

Classes: Package, Writer, XCFramework

Constant Summary collapse

KEYS_DIRECTORY =

The name of the directory that contains the keys

'.keys'.freeze
BUILD_DIRECTORY =

The name of the directory that contains the generated build

'Build'.freeze
SWIFT_PACKAGE_NAME =

The name of the Swift Package

'Keys'.freeze
SWIFT_PACKAGE_DIRECTORY =

The name of the directory that contains the generated Swift package

"#{KEYS_DIRECTORY}/Package".freeze
XCFRAMEWORK_DIRECTORY =

The name of the directory that contains the generated xcframework

"#{SWIFT_PACKAGE_NAME}.xcframework".freeze