Module: SecureKeys

Defined in:
lib/validation/utils/patterns.rb,
lib/keys.rb,
lib/version.rb,
lib/core/generator.rb,
lib/core/console/shell.rb,
lib/validation/scanner.rb,
lib/core/console/logger.rb,
lib/core/environment/ci.rb,
lib/core/globals/globals.rb,
lib/services/environment.rb,
lib/validation/validator.rb,
lib/core/utils/swift/swift.rb,
lib/core/utils/swift/writer.rb,
lib/validation/actions/scan.rb,
lib/core/utils/swift/package.rb,
lib/validation/utils/entropy.rb,
lib/core/environment/keychain.rb,
lib/core/utils/openssl/cipher.rb,
lib/validation/models/finding.rb,
lib/core/utils/swift/xcodeproj.rb,
lib/validation/globals/globals.rb,
lib/validation/utils/min_length.rb,
lib/validation/validation_issue.rb,
lib/core/utils/swift/xcframework.rb,
lib/validation/validation_result.rb,
lib/core/console/arguments/parser.rb,
lib/validation/models/scan_result.rb,
lib/validation/utils/weak_secrets.rb,
lib/core/console/arguments/handler.rb,
lib/core/console/arguments/fetchable.rb,
lib/validation/console/arguments/parser.rb,
lib/validation/console/arguments/scan/parser.rb,
lib/core/console/arguments/xcframework/parser.rb,
lib/validation/console/arguments/scan/handler.rb,
lib/core/console/arguments/xcframework/handler.rb

Overview

rubocop:disable Lint/Syntax, Metrics/ModuleLength

Defined Under Namespace

Modules: Core, Globals, OpenSSL, Services, Swift, Validation

Constant Summary collapse

VERSION =
'1.2.0'.freeze
SUMMARY =
'Secure Keys is a simple tool for managing your secret keys'.freeze
DESCRIPTION =
'Secure Keys is a simple tool to manage your secret keys in your iOS project'.freeze
HOMEPAGE_URI =
'https://github.com/derian-cordoba/secure-keys'.freeze
GEM_HOMEPAGE_URI =
'https://rubygems.pkg.github.com'.freeze

Class Method Summary collapse

Class Method Details

.runObject



11
12
13
14
15
16
17
# File 'lib/keys.rb', line 11

def self.run
  # Configure the argument parser
  Core::Console::Argument::Parser.new

  # Generate the keys
  Core::Generator.new.generate
end